@@ -33,17 +33,17 @@
 #include <tqstringlist.h>
 #include <tqdatastream.h>
 
-#include <kglobal.h>
-#include <kconfig.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
+#include <tdelocale.h>
 #include <knuminput.h>
 #include <dcopclient.h>
 #include <kiconloader.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kdesktopfile.h>
 #include <kcolorbutton.h>
 #include <kinputdialog.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <knotifydialog.h>
 #include <kstandarddirs.h>
 #include <kgenericfactory.h>
@@ -66,7 +66,7 @@ typedef KGenericFactory<ConfigDialog, TQWidget> KNemoFactory;
 K_EXPORT_COMPONENT_FACTORY( kcm_knemo, KNemoFactory("kcm_knemo") )
 
 ConfigDialog::ConfigDialog( TQWidget *parent, const char *name, const TQStringList& )
-    : KCModule( KNemoFactory::instance(), parent, name ),
+    : TDECModule( KNemoFactory::instance(), parent, name ),
       mLock( false ),
       mDlg( new ConfigDlg( this ) ),
       mColorVLines( 0x04FB1D ),
@@ -75,7 +75,7 @@ ConfigDialog::ConfigDialog( TQWidget *parent, const char *name, const TQStringLi
       mColorOutgoing( 0xFF7F08 ),
       mColorBackground( 0x313031 )
 {
-    KGlobal::locale()->insertCatalogue("kcm_knemo");
+    TDEGlobal::locale()->insertCatalogue("kcm_knemo");
     setupToolTipArray();
 
     // fill the backends combobox
@@ -87,10 +87,10 @@ ConfigDialog::ConfigDialog( TQWidget *parent, const char *name, const TQStringLi
     load();
 
     TQVBoxLayout* top = new TQVBoxLayout(this);
-    mDlg->pushButtonNew->setPixmap( SmallIcon( "filenew" ) );
-    mDlg->pushButtonDelete->setPixmap( SmallIcon( "editdelete" ) );
-    mDlg->pushButtonAddCommand->setPixmap( SmallIcon( "filenew" ) );
-    mDlg->pushButtonRemoveCommand->setPixmap( SmallIcon( "editdelete" ) );
+    mDlg->pushButtonNew->setPixmap( SmallIcon( "document-new" ) );
+    mDlg->pushButtonDelete->setPixmap( SmallIcon( "edit-delete" ) );
+    mDlg->pushButtonAddCommand->setPixmap( SmallIcon( "document-new" ) );
+    mDlg->pushButtonRemoveCommand->setPixmap( SmallIcon( "edit-delete" ) );
     mDlg->pushButtonUp->setPixmap( SmallIcon( "1uparrow" ) );
     mDlg->pushButtonDown->setPixmap( SmallIcon( "1downarrow" ) );
     mDlg->pushButtonAddToolTip->setPixmap( SmallIcon( "1rightarrow" ) );
@@ -109,7 +109,7 @@ ConfigDialog::ConfigDialog( TQWidget *parent, const char *name, const TQStringLi
                           "<b>Root</b> CheckBox.") );
 
     mSettingsDict.setAutoDelete( true );
-    setButtons( KCModule::Default | KCModule::Apply );
+    setButtons( TDECModule::Default | TDECModule::Apply | TDECModule::Help );
 
     connect( mDlg->pushButtonNew, TQT_SIGNAL( clicked() ),
              this, TQT_SLOT( buttonNewSelected() ) );
@@ -256,7 +256,7 @@ void ConfigDialog::load()
 {
     mSettingsDict.clear();
     mDlg->listBoxInterfaces->clear();
-    KConfig* config = new KConfig( "knemorc", true );
+    TDEConfig* config = new TDEConfig( "knemorc", true );
 
     config->setGroup( "General" );
     bool startKNemo = config->readBoolEntry( "StartKNemo", false );
@@ -264,7 +264,7 @@ void ConfigDialog::load()
     mDlg->tabWidgetConfiguration->setEnabled( startKNemo );
     mDlg->numInputPollInterval->setValue( config->readNumEntry( "PollInterval", 1 ) );
     mDlg->numInputSaveInterval->setValue( config->readNumEntry( "SaveInterval", 60 ) );
-    mDlg->lineEditStatisticsDir->setText( config->readEntry( "StatisticsDir", KGlobal::dirs()->saveLocation( "data", "knemo/" ) ) );
+    mDlg->lineEditStatisticsDir->setText( config->readEntry( "StatisticsDir", TDEGlobal::dirs()->saveLocation( "data", "knemo/" ) ) );
     mToolTipContent = config->readNumEntry( "ToolTipContent", 2 );
 
     // select the backend from the config file
@@ -361,7 +361,7 @@ void ConfigDialog::load()
 
 void ConfigDialog::save()
 {
-    KConfig* config = new KConfig( "knemorc", false );
+    TDEConfig* config = new TDEConfig( "knemorc", false );
 
     TQStringList list;
     TQDictIterator<InterfaceSettings> it( mSettingsDict );
@@ -431,7 +431,7 @@ void ConfigDialog::save()
     {
         // This call will implicitly start KNemo if it is not yet running.
         kapp->dcopClient()->send( "kded", "knemod", "reparseConfiguration()", TQString("") );
-        desktop->writeEntry( "X-KDE-Kded-autoload", true );
+        desktop->writeEntry( "X-TDE-Kded-autoload", true );
     }
     else
     {
@@ -439,7 +439,7 @@ void ConfigDialog::save()
         TQDataStream arg(data, IO_WriteOnly);
         arg << "knemod";
         kapp->dcopClient()->send("kded", "kded", "unloadModule(TQCString)", data);
-        desktop->deleteEntry( "X-KDE-Kded-autoload" );
+        desktop->deleteEntry( "X-TDE-Kded-autoload" );
     }
     desktop->sync();
     delete desktop;
@@ -493,7 +493,7 @@ void ConfigDialog::defaults()
     // Default misc settings
     mDlg->numInputPollInterval->setValue( 1 );
     mDlg->numInputSaveInterval->setValue( 60 );
-    mDlg->lineEditStatisticsDir->setText( KGlobal::dirs()->saveLocation( "data", "knemo/" ) );
+    mDlg->lineEditStatisticsDir->setText( TDEGlobal::dirs()->saveLocation( "data", "knemo/" ) );
     mDlg->comboBoxBackends->setCurrentItem( 0 );
     mDlg->textLabelBackendDescription->setText( KCMRegistry[0].description );
 
@@ -982,7 +982,7 @@ void ConfigDialog::checkBoxStartKNemoToggled( bool on )
 {
     if ( on )
     {
-        KConfig* config = new KConfig( "knemorc", false );
+        TDEConfig* config = new TDEConfig( "knemorc", false );
         config->setGroup( "General" );
         if ( config->readBoolEntry( "FirstStart", true ) )
         {
